@@ -16,7 +16,7 @@ CONFIG_SCHEMA = output.FLOAT_OUTPUT_SCHEMA.extend(
     {
         cv.GenerateID(): cv.declare_id(GP8403Output),
         cv.GenerateID(CONF_GP8403_ID): cv.use_id(GP8403),
-        cv.Required(CONF_CHANNEL): cv.one_of(0, 1),
+        cv.Required(CONF_CHANNEL): cv.int_range(min=0, max=1),
     }
 ).extend(cv.COMPONENT_SCHEMA)
 
